@@ -29,7 +29,8 @@ import gi
 gi.require_version('Grl', '0.3')
 from gi.repository import GLib, GObject
 from gnomemusic.query import Query
-from gnomemusic import log, TrackerWrapper
+from gnomemusic import log
+from gnomemusic.trackerwrapper import TrackerWrapper
 import logging
 import os
 os.environ['GRL_PLUGIN_RANKS'] = ("grl-local-metadata:5,"
@@ -80,6 +81,8 @@ class Grilo(GObject.GObject):
     _theaudiodb_api_key = "195003"
 
     sources = GObject.Property()
+    cover_sources = GObject.Property(type=bool, default=False)
+    tracker_available = GObject.Property(type=bool, default=False)
 
     def __repr__(self):
         return '<Grilo>'
@@ -117,9 +120,17 @@ class Grilo(GObject.GObject):
         self.changes_pending = {'Albums': False, 'Artists': False, 'Songs': False}
         self.pending_changed_medias = []
 
+        self._thumbnail_sources = []
+        self._thumbnail_sources_timeout = None
+
         self.registry = Grl.Registry.get_default()
 
-        self.sparqltracker = TrackerWrapper().tracker
+        self._tracker_wrapper = TrackerWrapper()
+        self.tracker_sparql = self._tracker_wrapper.props.tracker
+        self._tracker_wrapper.bind_property(
+            "tracker-available", self, "tracker-available",
+            GObject.BindingFlags.BIDIRECTIONAL |
+            GObject.BindingFlags.SYNC_CREATE)
 
         self._find_sources()
 
@@ -201,6 +212,14 @@ class Grilo(GObject.GObject):
         self.emit('changes-pending')
         return False
 
+    @log
+    def _trigger_art_update(self):
+        self._thumbnail_sources_timeout = None
+        if len(self._thumbnail_sources) > 0:
+            self.props.cover_sources = True
+
+        return GLib.SOURCE_REMOVE
+
     @log
     def _on_source_added(self, pluginRegistry, mediaSource):
         if ("net:plaintext" in mediaSource.get_tags()
@@ -212,6 +231,14 @@ class Grilo(GObject.GObject):
                     "Failed to unregister {}".format(mediaSource.get_id()))
             return
 
+        if Grl.METADATA_KEY_THUMBNAIL in mediaSource.supported_keys():
+            self._thumbnail_sources.append(mediaSource)
+            if not self._thumbnail_sources_timeout:
+                # Aggregate sources being added, for example when the
+                # network comes online.
+                self._thumbnail_sources_timeout = GLib.timeout_add_seconds(
+                    5, self._trigger_art_update)
+
         id = mediaSource.get_id()
         logger.debug("new grilo source %s was added", id)
         try:
@@ -478,6 +505,7 @@ class Grilo(GObject.GObject):
                 cursor = conn.query_finish(res)
             except GLib.Error as err:
                 logger.warning("Error: {}, {}".format(err.__class__, err))
+                self.props.tracker_available = False
                 callback(False)
                 return
 
@@ -485,8 +513,12 @@ class Grilo(GObject.GObject):
 
         # TODO: currently just checks tracker, should work with any
         # queryable supported Grilo source.
-        self.sparqltracker.query_async(Query.all_songs_count(), None,
-                                       songs_query_cb, None)
+        if not self.props.tracker_available:
+            callback(False)
+            return
+
+        self.tracker_sparql.query_async(
+            Query.all_songs_count(), None, songs_query_cb, None)
 
 
 grilo = Grilo()
